![](https://raw.githubusercontent.com/PttCodingMan/PyPtt/master/logo/facebook_cover_photo_2.png)
# PyPtt
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/PyPtt)
[![Package Version](https://img.shields.io/pypi/v/PyPtt.svg)](https://pypi.python.org/pypi/PyPtt)
![PyPI - Downloads](https://img.shields.io/pypi/dm/PyPtt)
[![Build Status](https://travis-ci.org/PttCodingMan/PyPtt.svg?branch=master)](https://travis-ci.org/PttCodingMan/PyPtt)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/940fe61df0a0443ba883307e11e7b22d)](https://www.codacy.com/manual/PttCodingMan/PyPtt?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=PttCodingMan/PyPtt&amp;utm_campaign=Badge_Grade)
[![License: LGPL v3](https://img.shields.io/badge/License-LGPL%20v3-blue.svg)](https://www.gnu.org/licenses/lgpl-3.0)
[![chatroom icon](https://patrolavia.github.io/telegram-badge/chat.png)](https://t.me/PyPtt)
[![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](http://paypal.me/CodingMan)

#### PyPtt (PTT Library) 是一套 Pure Python PTT API。具備大部分常用功能，無論推文、發文、爬蟲、寄信、發 P 幣、丟水球或者追蹤帳號，你都可以在這裡找到完整的使用範例
#### 可自由選擇 WebSocket 或者 Telnet 來連線，並支援繁體中文與英文顯示
#### API 的詳細範例與參數說明 [PyPtt 文件](https://github.com/PttCodingMan/PyPtt/tree/master/doc)
#### Pypi: https://pypi.org/project/PyPtt/
<img src="https://i.imgur.com/wfaf8Bk.gif" width="480">

## 為什麼選擇 PyPtt
#### 完整的支援: PyPtt 是目前支援最完整的 PTT API，除了 PTT 也相容於 PTT2，詳細範例請參考 [PyPtt 文件](https://github.com/PttCodingMan/PyPtt/tree/master/doc)
#### 高效能爬蟲: 登入式爬蟲，除了可以取得即時的推文，也比網頁式爬蟲擁有更好的效能 [效能比較表](https://hackmd.io/@CodingMan/crawlerbenchmark)
#### 快速的客服: 如果有任何問題你可以在 [![chatroom icon](https://patrolavia.github.io/telegram-badge/chat.png)](https://t.me/PyPtt) 找到我
#### 完整的測試: 你可以在 [![Build Status](https://travis-ci.org/PttCodingMan/PyPtt.svg?branch=master)](https://travis-ci.org/PttCodingMan/PyPtt) 找到完整測試結果
#### 程式碼品質: 你可以在 [![Codacy Badge](https://api.codacy.com/project/badge/Grade/940fe61df0a0443ba883307e11e7b22d)](https://www.codacy.com/manual/PttCodingMan/PyPtt?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=PttCodingMan/PyPtt&amp;utm_campaign=Badge_Grade) 找到程式碼品質報告與評等

## 版本
#### [![Package Version](https://img.shields.io/pypi/v/PyPtt.svg)](https://pypi.python.org/pypi/PyPtt)

## 取得
#### 安裝
#### Windows 使用 pip, Linux and Mac 使用 pip3
```bash
pip install PyPtt
```

## 回報問題
#### 1. 請閱讀 [PyPtt 文件](https://github.com/PttCodingMan/PyPtt/tree/master/doc) 確認使用方法無誤並確認你所使用的版本為 [![Package Version](https://img.shields.io/pypi/v/PyPtt.svg)](https://pypi.python.org/pypi/PyPtt) 如果是舊版本請更新後複測
#### 2. 如果問題還是存在，請參考文件中的 [初始設定](https://github.com/PttCodingMan/PyPtt/tree/master/doc#%E5%88%9D%E5%A7%8B%E8%A8%AD%E5%AE%9A) 將 log_level 調整成 PTT.log.level.TRACE 後截圖並附上使用 PyPtt 的相關程式碼
#### 3. 開個 [issue](https://github.com/PttCodingMan/PyPtt/issues/new) 追蹤問題也可以直接問我 [![chatroom icon](https://patrolavia.github.io/telegram-badge/chat.png)](https://t.me/PyPtt)

## 需求
#### Python ≥ 3.6

## 相依函式庫
#### progressbar2
#### websockets
#### uao
#### beautifulsoup4 (Since 0.8.25)
#### requests (Since 0.8.25)

## 贊助
#### 在這個 github 的小園地，用熱血的心為您打造在 PTT 翱翔的翅膀
#### 希望您可以贊助這雙翅膀，讓我們一起飛得更遠
####
#### [![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](http://paypal.me/CodingMan)
####
#### XMR
#### 448CUe2q4Ecf9tx6rwanrqM9kfCwqpNbhJ5jtrTf9FHqHNq7Lvv9uBoQ74SEaAu9FFceNBr6p3W1yhqPcxPPSSTv2ctufnQ

## 贊助清單

#### 尚無贊助
